Env

Struct Env 

pub struct Env { /* private fields */ }
Current context of environment variable parsing.

Env keeps track of nesting by storing the name of the “current” variable. A type’s parser may choose to read the value of the current variable using value, or use it to parse its fields using nest and field.

Implementations

Source

impl Env

pub fn value(&self) -> Result<OsString, Error>

Read the value of the current variable.

Errors

Returns Error::Missing if the current variable is missing.

Examples
enum Color {
    Orange,
    Blue,
}

impl Tenvy for Color {
   fn from_env(env: &Env) -> Result<Self, Error> {
      #[derive(Debug, thiserror::Error)]
      #[error("expected `orange` or `blue`")]
      struct InvalidColor;

      match env.value()?.to_str() {
          Some("orange") => Ok(Self::Orange),
          Some("blue") => Ok(Self::Blue),
          _ => Err(Error::invalid_value(env, InvalidColor)),
      }
   }
}
pub fn nest<K: AsRef<OsStr>>(&self, field: K) -> Self

Construct a new context for a field, i.e. append field to the current variable name. The separator _ is added automatically.

pub fn field<K: AsRef<OsStr>, T: Tenvy>(&self, field: K) -> Result<T, Error>

Parse a value in a nested context.

Examples
impl Tenvy for Database {
    fn from_env(env: &Env) -> Result<Self, Error> {
        Ok(Self {
            url: env.field("URL")?,
        })
    }
}